.. -*- mode: rst -*-

|license|_ |codacy|_ |docs|_ |pypi|_

.. |license| image:: https://img.shields.io/badge/License-MIT-yellow.svg
.. _license: https://opensource.org/licenses/MIT

.. |codacy| image:: https://api.codacy.com/project/badge/Grade/983bcf3973094f20ba4f516d6891c5f7
.. _codacy: https://www.codacy.com/app/arthurpaulino/miraiml?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=arthurpaulino/miraiml&amp;utm_campaign=Badge_Grade

.. |docs| image:: https://readthedocs.org/projects/miraiml/badge/?version=latest
.. _docs: https://readthedocs.org/projects/miraiml/

.. |pypi| image:: https://badge.fury.io/py/MiraiML.svg
.. _pypi: https://pypi.org/project/MiraiML/

MiraiML
=======

    Mirai: `future` in japanese.

MiraiML is an asynchronous engine for continuous & autonomous machine learning,
built for real-time usage.

Usage
-----

1. Install: ``$ pip install miraiml``
2. Now, inside a Python environment, import the main classes:

>>> from miraiml import HyperSearchSpace, Config, Engine

Some didactic tutorials can be found in the examples_ directory. Or `Read the
Docs`_ for a better understanding of MiraiML.

Contributing
------------

Please, follow the guidelines_ if you want to be part of this project.

.. _examples: https://github.com/arthurpaulino/miraiml/tree/master/examples
.. _Read the Docs: https://miraiml.readthedocs.io/en/latest/
.. _guidelines: https://github.com/arthurpaulino/miraiml/blob/master/CONTRIBUTING.md
